from django import forms
from django.forms.utils import flatatt
from django.utils.safestring import mark_safe


class IconPickerWidget(forms.TextInput):
    class Media:
        css = {'all': (
            "https://cdn.jsdelivr.net/npm/uikit@3.4.0/dist/css/uikit.min.css",
            'https://fonts.googleapis.com/icon?family=Material+Icons',
            'icon_picker_widget/css/style.css',)}
        js = ("https://code.jquery.com/jquery-3.4.1.min.js",
              'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js',
              'https://cdn.jsdelivr.net/npm/uikit@3.4.0/dist/js/uikit.min.js',
              'https://cdn.jsdelivr.net/npm/uikit@3.4.0/dist/js/uikit-icons.min.js',
              'icon_picker_widget/js/npick.js')

    def render(self, name, value, attrs=None, **kwargs):
        super().render(name, value, attrs)
        flat_attrs = flatatt(attrs)
        atr_id = attrs['id']
        html = f'  <input  {flat_attrs} value="{value}" type="text" class="form-contol use-material-icon-picker" id="{atr_id}" name="{name}"> '
        return mark_safe(html)



from setuptools import setup, find_packages

with open("README.md", encoding='utf-8') as fp:
    long_description = fp.read()

setup(
    name="django-material-icon-widget",
    version="0.1.1",
    license="MIT",
    description="Icon Picker for admin panel In Django",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Adi Eyal",
    author_email="adi@openup.org.za",
    url="https://github.com/adieyal/django-material-icon-widget",
    download_url="https://github.com/adieyal/django-material-icon-widget/archive/v0.1.1.tar.gz",
    packages=find_packages(),
    keywords=["widget", "utility"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
